Tss

Struct Tss 

pub struct Tss {
    tss: UnsafeCell<TaskStateSegment>,
    ist1: AlignedStack<8192>,
    ist2: AlignedStack<8192>,
    ist3: AlignedStack<8192>,
    ist4: AlignedStack<8192>,
}
Owns the TaskStateSegment and its four IST stacks; must not move after Tss::init (the GDT descriptor points to it).

Fields

tss: UnsafeCell<TaskStateSegment>ist1: AlignedStack<8192>ist2: AlignedStack<8192>ist3: AlignedStack<8192>ist4: AlignedStack<8192>

Implementations

Source

impl Tss

pub const fn new() -> Self

Create a new, uninitialized Tss; call Tss::init to populate it.

pub unsafe fn init(&'static self)

Build the TSS with RSP0 pointing to 0 and the predefined IST stacks

Safety

This method must be called exactly once before Tss::tss is called to avoid undefined behavior and multiple mutable references.

pub unsafe fn tss(&'static self) -> &'static TaskStateSegment

Getter for Tss::tss, returns a reference

Safety

The caller must guarantee that there are no mutable references or pointers to self.tss

pub unsafe fn set_rsp0(&self, new_rsp0: VirtAddr)

Setter for TSS.RSP0

Safety

The caller must guarantee the following:

  • That Tss::init has already been called
  • This method is only called on the CPU which owns this TSS
  • That no refs/ptrs from Tss::tss are held when this is called
  • new_rsp0 is a valid pointer to a valid, mapped kernel stack